containertools.get_element_starting_at_exactly_offset
=====================================================

.. autofunction:: abjad.tools.containertools.get_element_starting_at_exactly_offset.get_element_starting_at_exactly_offset
   :noindex:
